{% extends "wiki/article.html" %}
{% load wiki_tags i18n humanize %}

{% block pagetitle %}{% trans "Attachments" %}: {{ article.current_revision.title }}{% endblock %}

{% block wiki_contents_tab %}
<div class="row-fluid">
  <div class="span8">
    <p class="lead">{% trans "The following files are available for this article. Copy the markdown tag to directly refer to a file from the article text." %}</p>


    <table class="table table-bordered table-striped">
    {% for attachment in attachments %}
      <tr>
        <th colspan="4">
          <h4>
            <a href="{% url 'wiki:attachments_download' path=urlpath.path article_id=article.id attachment_id=attachment.id %}">{{ attachment.current_revision.get_filename }}</a>
            <span class="badge">{{ attachment.current_revision.created|naturaltime }}</span>
            {% if attachment.current_revision.deleted %}
            <span class="badge badge-important">{% trans "deleted" %}</span>
            {% endif %}
          </h4>
        </th>
      </tr>
      <tr>
        <th>{% trans "Markdown tag" %}</th>
        <th>{% trans "Uploaded by" %}</th>
        <th>{% trans "Size" %}</th>
        <td style="text-align: right; white-space: nowrap;" rowspan="2">
          {% if attachment|can_write:user %}
            <p>
            {% if not attachment.current_revision.deleted %}
              <a href="{% url 'wiki:attachments_replace' path=urlpath.path article_id=article.id attachment_id=attachment.id %}" class="btn">{% trans "Replace" %}</a>
              {% if 'attachment.article = article' %}
                <a href="{% url 'wiki:attachments_delete' path=urlpath.path article_id=article.id attachment_id=attachment.id %}" class="btn">{% trans "Delete" %}</a>
              {% else %}
                <a href="{% url 'wiki:attachments_delete' path=urlpath.path article_id=article.id attachment_id=attachment.id %}" class="btn">{% trans "Detach" %}</a>
              {% endif %}
            {% else %}
              {% if attachment.current_revision.previous_revision.id %}
              <form method="POST" action="{% url 'wiki:attachments_revision_change' path=urlpath.path article_id=article.id attachment_id=attachment.id revision_id=attachment.current_revision.previous_revision.id %}">
                {% csrf_token %}
                <button class="btn">
                  {% trans "Restore" %}
                </button>
              </form>
              {% endif %}
            {% endif %}
            </p>
          {% endif %}
          <p>
          <a href="{% url 'wiki:attachments_history' path=urlpath.path article_id=article.id attachment_id=attachment.id %}">
            <span class="icon-time"></span>
            {% trans "File history" %} ({{ attachment.attachmentrevision_set.all.count }} {% trans "revisions" %})
          </a>
          </p>
        </td>
      </tr>
      <tr>
        <td><code>[attachment:{{ attachment.id }}]</code></td>
        <td>
        {% include "wiki/includes/revision_info.html" with revision=attachment.current_revision hidedate=1 hidenumber=1 %}
        </td>
        <td>{{ attachment.current_revision.get_size|filesizeformat }}</td>
      </tr>
    {% empty %}
      <tr>
        <td>
          <p style="margin-bottom: 20px;"><em>{% trans "There are no attachments for this article." %}</em></p>
        </td>
      </tr>
    {% endfor %}
    </table>
  </div>
  {% if article|can_write:user %}
  <div class="span4" style="min-width: 330px;">
    <div class="accordion">

      <div class="accordion-group">
        
        <div class="accordion-heading">
          <a class="accordion-toggle" href="#collapse_upload" data-toggle="collapse">
            <h3>{% trans "Upload new file" %} <span class="icon-upload"></span></h3>
          </a>
        </div>
        
        <div id="collapse_upload" class="accordion-body collapse{% if form.errors %} in{% endif %}">
          <div class="accordion-inner">
            {% if anonymous_disallowed %}
              {% include "wiki/includes/anonymous_blocked.html" %}
            {% else %}
            <form method="POST" class="form-vertical" id="attachment_form" enctype="multipart/form-data">
              {% wiki_form form %}
              <button type="submit" name="save" value="1" class="btn btn-large">
                {% trans "Upload file" %}
              </button>
            </form>
            {% endif %}
          </div>
        </div>
      
      </div>
      <div class="accordion-group">
        <div class="accordion-heading">
          <a class="accordion-toggle" data-toggle="collapse">
            <h3>{% trans "Search and add file" %} <span class="icon-plus-sign"></span></h3>
          </a>
        </div>
        
        <div id="collapse_add" class="accordion-body collapse">
          <div class="accordion-inner">
            <p>{% trans "You can reuse files from other articles. These files are subject to updates on other articles which may or may not be a good thing." %}</p>
            <form method="GET" action="{% url 'wiki:attachments_search' path=urlpath.path article_id=article.id %}" class="form-search">
              {{ search_form.query }}
              <button class="btn">
                <span class="icon-search"></span>
                {% trans "Search" %}
              </button>
            </form>
          </div>
        </div>
      </div>
      
    </div>
  </div>
  {% endif %}
  
</div>
  
{% endblock %}

