{% load sekizai_tags i18n %}<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <title>{% block pagetitle %}{% endblock %} -- django-\/\/  i K |</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="">
    <meta name="author" content="www.django-wiki.org">

    <!-- Le styles -->
    <link href="{{ STATIC_URL }}wiki/bootstrap/css/bootstrap.css" rel="stylesheet">
    <link href="{{ STATIC_URL }}wiki/bootstrap/css/bootstrap-responsive.min.css" rel="stylesheet">
    
    <!-- TODO: Put all this stuff in Less -->
    <style media="print">
      .navbar,
      .nav-tabs li a,
      #article-breadcrumbs
      {display: none;}
    </style>
    <style media="all">
      #div_id_title .asteriskField{display:none}
      #id_title {font-size: 20px; height: 30px; padding: 6px; width: 98%;}
      #id_summary {width: 98%; padding: 6px;}
      
      h1#article-title {font-size: 2em; margin-top: -5px;}
      
      #article_edit_form label {max-width: 100px;}
      #article_edit_form .controls {margin-left: 120px;}
      
      .form-horizontal label { font-size: 16px; font-weight: normal; color: #777;}
  
      .settings-form label {min-width: 250px; font-size: inherit; font-weight: normal;}
      .settings-form .controls {margin-left: 270px;}
      .settings-form select {}
      .settings-form .form-actions { padding-left: 270px; }
      
      #attachment_form #id_description
      { width: 95% }
      
      #edit_sidebar .accordion {margin-bottom: 5px;}
      
      .wiki-article div.toc {
        margin: 10px 0;
        background: #f9f9f9;
        padding: 10px;
        width: 300px;
        border: 1px solid #CCC;
      }
            
      .wiki-article a.linknotfound {color: #C87;}
      
      .wiki-article pre {
        max-width: 700px;
      }
      
      input[type=file] {float: none; width: auto;}
      .asteriskField { font-size: 20px; margin-left: 5px;}
      
      .notification-list .since {
        font-size: 80%;
        color: #CCC;
      }
      
      .directory-toolbar .filter-clear { margin-right: 10px; position: relative; top: 5px; }
      
      .accordion-heading h3 {margin: 0;}
      
      .breadcrumb .icon-bar {
          display: block;
          width: 18px;
          height: 2px;
          background-color: rgb(245, 245, 245);
          border-radius: 1px 1px 1px 1px;
          box-shadow: 0px 1px 0px rgba(0, 0, 0, 0.25);
          margin-top: 3px;
      }
      .breadcrumb .icon-bar:first-child{margin-top: 0;}
      
      #navbar_wiki_search input.search-query {width: 80px;}
      
    </style>
    
    <script src="{{ STATIC_URL }}wiki/js/jquery.min.js"></script>
    <script src="{{ STATIC_URL }}wiki/js/core.js"></script>
    <script src="{{ STATIC_URL }}wiki/bootstrap/js/bootstrap.min.js"></script>
    {% render_block "css" %}
    {% render_block "js" %}
    
    <!-- Le HTML5 shim, for IE6-8 support of HTML5 elements -->
    <!--[if lt IE 9]>
      <script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
    <![endif]-->

  </head>

  <body>

    {% block wiki_body %}
    
    {% block navbar %}
    <div class="navbar navbar-fixed-top navbar-inverse">
      <div class="navbar-inner">
        <div class="container">
          <a class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </a>
          <a class="brand" href="{% url 'wiki:root' %}">django-wiki</a>
          <form class="navbar-search pull-right" id="navbar_wiki_search" method="GET" action="asdsd">
            <span class="icon-search"></span>
            <input type="text" class="search-query" placeholder="{% trans "Search..." %}" />
          </form>
          <div class="pull-right">
            {% if user.is_authenticated %}
            <ul class="nav">
              {% include "wiki/plugins/notifications/menubaritem.html" %}
              <li class="dropdown">
                <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                  <span class="icon-user"></span>
                  {{ user }}
                  <b class="caret"></b>
                </a>
                <ul class="dropdown-menu">
                  <li>
                    <a href="{% url 'wiki:logout' %}">
                      <span class="icon-off"></span>
                      {% trans "Log out" %}
                    </a>
                  </li>
                </ul>
              </li>
            </ul>
            {% else %}
            <ul class="nav">
              <li>
                <a href="{% url 'wiki:login' %}">{% trans "Log in" %}</a>
              </li>
              <li>
                <a href="{% url 'wiki:signup' %}">{% trans "Sign up" %}</a>
              </li>
            </ul>
            {% endif %}
          </div>
          <div class="nav-collapse">
            <ul class="nav">
              <li class="active"><a href="/">Home</a></li>
              <li><a href="https://github.com/benjaoming/django-wiki" target="_blank">About</a></li>
            </ul>
          </div><!--/.nav-collapse -->
        </div>
      </div>
    </div>
    {% endblock %}

    <div class="container" style="margin-top: 60px;">
      {% if messages %}
        {% for message in messages %}
          <div class="alert alert-{{ message.tags }}">
            <a class="close" data-dismiss="alert" href="#">&times;</a>
            {{ message }}
          </div>
        {% endfor %}
      {% endif %}
      {% block wiki_breadcrumbs %}{% endblock %}
      {% block wiki_contents %}
      <h1>Bootstrap starter template</h1>
      <p>Use this document as a way to quick start any new project.<br> All you get is this message and a barebones HTML document.</p>
      {% endblock %}
      
      <div style="padding: 30px 0;">
      <footer>
        <hr />
        <a href="https://github.com/benjaoming/django-wiki" class="pull-right"><img src="{{ STATIC_URL }}wiki/img/github_icon.png" /></a>
        {% block footer_prepend %}
        {% endblock %}
        <p>Powered by <a href="http://www.django-wiki.org">django-wiki</a>, an open source application under the <a href="http://www.gnu.org/licenses/quick-guide-gplv3.html">GPLv3</a> license. Let knowledge be the cure.</p>
        <div style="clear: both"></div>
      </footer>
      </div>

    </div> <!-- /container -->

    {% endblock %}

  </body>
</html>

