{% extends "wiki/base.html" %}
{% load wiki_tags i18n %}

{% block pagetitle %}Permission Denied{% endblock %}

{% block wiki_contents %}
  <h1 class="page-header">{% trans "Permission Denied" %}</h1>
  <p class="alert denied">
    {% trans "Sorry, you don't have permission to view this page." %}
  </p>
{% endblock %}

