{% extends "wiki/base.html" %}
{% load wiki_tags i18n %}

{% block wiki_body %}

  {% if revision %}
    <div class="alert alert-info">
      <strong>{% trans "Previewing revision" %}:</strong>
      {% include "wiki/includes/revision_info.html" %}
    </div>
  {% endif %}

  {% if merge %}
    <div class="alert alert-info">
      <strong>{% trans "Previewing merge between" %}:</strong>
      {% include "wiki/includes/revision_info.html" with revision=merge1 %}
      <strong>{% trans "and" %}</strong>
      {% include "wiki/includes/revision_info.html" with revision=merge2 %}
    </div>
  {% endif %}

  <h1 class="page-header">{{ title }}</h1>

  {% if revision and revision.deleted %}
    <div class="warning">
      <strong>{% trans "This revision has been deleted." %}</strong> 
      <p>{% trans "Restoring to this revision will mark the article as deleted." %}</p>
    </div>
  {% else %}
    {% wiki_render article content %}
  {% endif %}

{% endblock %}
