{% extends "wiki/base.html" %}
{% load i18n wiki_tags %}
{% block pagetitle %}{% trans "Log in" %}{% endblock %}

{% block wiki_contents %}
<h1 class="page-header">{% trans "Please log in" %}</h1>
<form method="POST" class="form-horizontal">
{% wiki_form form %}
<div class="form-actions">
    <button type="submit" name="save_changes" class="btn btn-primary btn-large">
      <span class="icon-lock"></span>
      {% trans "Log me in..." %}
    </button>
</div>
</form>

<p>
  {% trans "Don't have an account?" %} <a href="{% url 'wiki:signup' %}">{% trans "Sign up" %} &raquo;</a>
</p>

<script type="text/javascript">
  $('#id_username').focus();
</script>
{% endblock %}
