{% extends "wiki/base.html" %}
{% load wiki_tags i18n %}

{% block pagetitle %}{{ article.current_revision.title }}{% endblock %}

{% block wiki_breadcrumbs %}
{% include "wiki/includes/breadcrumbs.html" %}
{% endblock %}

{% block wiki_contents %}

  <div class="" style="margin-top: 20px;">
    <ul class="nav nav-pills" style="border-bottom: 1px solid #EEE;">
      <li class="pull-left">
        <h1 id="article-title">
          {{ article.current_revision.title }}
          <small style="font-size: 14px;">
            {% if urlpath.parent %}
            <a href="{% url 'wiki:get' path=urlpath.path %}"><span class="icon-bookmark"></span> {{ urlpath.slug }}</a>
            {% endif %}
            {% if article.current_revision.locked %}
              <span class="icon-lock"></span> {% trans "locked" %}
            {% endif %}
          </small>
        </h1>
      </li>
      {% include "wiki/includes/article_menu.html" %}
    </ul>
    <div>
      {% block wiki_contents_tab %}
      {% wiki_render article %}
      {% endblock %}
    </div>
  </div>

{% endblock %}

{% block footer_prepend %}
  <p style="margin-bottom: 10px;"><em>{% trans "This article was last modified:" %} {{ article.current_revision.modified }}</em></p>
{% endblock %}
