# Generated by Django 1.11.27 on 2020-01-10 10:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wiki', '0005_remove_attachments_and_images'),
    ]

    operations = [
        migrations.AlterField(
            model_name='urlpath',
            name='level',
            field=models.PositiveIntegerField(editable=False),
        ),
        migrations.AlterField(
            model_name='urlpath',
            name='lft',
            field=models.PositiveIntegerField(editable=False),
        ),
        migrations.AlterField(
            model_name='urlpath',
            name='rght',
            field=models.PositiveIntegerField(editable=False),
        ),
    ]
