# Generated by Django 1.11.5 on 2017-09-07 19:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wiki', '0004_increase_slug_size'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='attachment',
            name='current_revision',
        ),
        migrations.RemoveField(
            model_name='attachmentrevision',
            name='attachment',
        ),
        migrations.RemoveField(
            model_name='attachmentrevision',
            name='previous_revision',
        ),
        migrations.RemoveField(
            model_name='attachmentrevision',
            name='user',
        ),
        migrations.DeleteModel(
            name='Attachment',
        ),
        migrations.DeleteModel(
            name='AttachmentRevision',
        ),
        migrations.DeleteModel(
            name='Image',
        ),
        migrations.DeleteModel(
            name='ImageRevision',
        ),
    ]
