/* -------------------------------------------------------------------
// markItUp!
// By Jay Salvat - http://markitup.jaysalvat.com/
// ------------------------------------------------------------------*/

/*label[for=id_content] {float: none; clear: both; width: 100%; display: block;}*/

.markItUp {padding: 0; width: auto;}

textarea.markItUp {font-size: 16px; padding: 10px; float: none; display: block; width: 100%; height: 400px; font-size: 13px; color: #222; }

.markItUpContainer {margin-right: 20px; width: -20px;}

.markItUp .markItUpButton1 a {
	background-image:url(images/h1.png); 
}
.markItUp .markItUpButton2 a {
	background-image:url(images/h2.png); 
}
.markItUp .markItUpButton3 a {
	background-image:url(images/h3.png); 
}
.markItUp .markItUpButton4 a {
	background-image:url(images/h4.png); 
}
.markItUp .markItUpButton5 a {
	background-image:url(images/h5.png); 
}
.markItUp .markItUpButton6 a {
	background-image:url(images/h6.png); 
}

.markItUp .markItUpButton7 a {
	background-image:url(images/bold.png);
}
.markItUp .markItUpButton8 a {
	background-image:url(images/italic.png);
}

.markItUp .markItUpButton9 a {
	background-image:url(images/list-bullet.png);
}
.markItUp .markItUpButton10 a {
	background-image:url(images/list-numeric.png);
}

/*.markItUp .markItUpButton11 a {
	background-image:url(images/picture.png); 
}
.markItUp .markItUpButton12 a {
	background-image:url(images/link.png);
}*/

.markItUp .markItUpButton11 a	{
	background-image:url(images/quotes.png);
}
.markItUp .markItUpButton12 a	{
	background-image:url(images/code.png);
}

.markItUp .preview a {
	background-image:url(images/preview.png);
}
