# Generated by Django 4.2.5 on 2023-09-21 05:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("wiki", "0006_auto_20200110_1003"),
    ]

    operations = [
        migrations.AlterField(
            model_name="articleforobject",
            name="content_type",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="content_type_set_for_%(class)s",
                to="contenttypes.contenttype",
                verbose_name="content type",
            ),
        ),
    ]
